@@ -58,7 +58,7 @@ class NotificationHandler(object):
         
         # make hash
         m = hashlib.md5()
-        m.update(timestamp)
+        m.update(str(timestamp))
         m.update(ebaysuds_config.get('keys', 'dev_id'))
         m.update(ebaysuds_config.get('keys', 'app_id'))
         m.update(ebaysuds_config.get('keys', 'cert_id'))
